@@ -5,26 +5,33 @@ from typing import List, Optional
 from nonebot.rule import Rule
 from nonebot import get_driver
 from nonebot.typing import T_State
-from nonebot.params import State, Depends
+from nonebot.params import Depends
 from nonebot.adapters.onebot.v11 import MessageSegment, MessageEvent, unescape
 
+from .config import memes_config
+
 ARG_KEY = "ARG"
 ARGS_KEY = "ARGS"
 REGEX_DICT = "REGEX_DICT"
 REGEX_GROUP = "REGEX_GROUP"
 REGEX_ARG = "REGEX_ARG"
 
+command_start = memes_config.memes_command_start or "|".join(
+    get_driver().config.command_start
+)
+
 
 def regex(pattern: str) -> Rule:
-    def checker(event: MessageEvent, state: T_State = State()) -> bool:
+    def checker(event: MessageEvent, state: T_State) -> bool:
         msg = event.get_message()
         msg_seg: MessageSegment = msg[0]
         if not msg_seg.is_text():
             return False
 
         seg_text = str(msg_seg).lstrip()
-        start = "|".join(get_driver().config.command_start)
-        matched = re.match(rf"(?:{start})(?:{pattern})", seg_text, re.IGNORECASE | re.S)
+        matched = re.match(
+            rf"(?:{command_start})(?:{pattern})", seg_text, re.IGNORECASE | re.S
+        )
         if not matched:
             return False
 
@@ -57,9 +64,9 @@ def regex(pattern: str) -> Rule:
 
 
 def Args(num: Optional[int] = None):
-    async def dependency(state: T_State = State()):
+    async def dependency(state: T_State):
         args: List[str] = state[ARGS_KEY]
-        if num and len(args) != num:
+        if num is not None and len(args) != num:
             return
         return args
 
@@ -67,7 +74,7 @@ def Args(num: Optional[int] = None):
 
 
 def RegexArg(key: str):
-    async def dependency(state: T_State = State()):
+    async def dependency(state: T_State):
         args: dict = state[REGEX_DICT]
         return args.get(key, None)
 
@@ -75,9 +82,9 @@ def RegexArg(key: str):
 
 
 def RegexArgs(num: Optional[int] = None):
-    async def dependency(state: T_State = State()):
+    async def dependency(state: T_State):
         args: List[str] = list(state[REGEX_GROUP])
-        if num and len(args) != num:
+        if num is not None and len(args) != num:
             return
         return args
 
@@ -85,7 +92,7 @@ def RegexArgs(num: Optional[int] = None):
 
 
 def Arg():
-    async def dependency(state: T_State = State()):
+    async def dependency(state: T_State):
         arg: str = state[ARG_KEY]
         if arg:
             return arg
